@@ -69,9 +69,10 @@ starwars %>%
 
 ## -----------------------------------------------------------------------------
 starwars %>%
-  transmute(
+  mutate(
     height_m = height / 100,
-    BMI = mass / (height_m^2)
+    BMI = mass / (height_m^2),
+    .keep = "none"
   )
 
 ## -----------------------------------------------------------------------------
