@@ -13,6 +13,17 @@ test_that("cur_group() works", {
 
 })
 
+test_that("cur_group() works with empty grouped data frame (#6304)", {
+  df <- tibble(x = integer())
+  gdf <- group_by(df, x)
+
+  out <- mutate(df, y = cur_group())
+  expect_identical(out$y, tibble())
+
+  out <- mutate(gdf, y = cur_group())
+  expect_identical(out$y, tibble(x = integer()))
+})
+
 test_that("cur_group_idx() gives unique id", {
   df <- tibble(x = c("b", "a", "b"))
   gf <- group_by(df, x)
@@ -27,38 +38,6 @@ test_that("cur_group_idx() gives unique id", {
   )
 })
 
-
-test_that("cur_data() gives current data without groups, cur_data_all() includes groups", {
-  df <- tibble(x = c("b", "a", "b"), y = 1:3)
-  gf <- group_by(df, x)
-
-  expect_equal(
-    df %>% summarise(x = list(cur_data())) %>% pull(),
-    list(df)
-  )
-
-  expect_equal(
-    gf %>% summarise(x = list(cur_data())) %>% pull(),
-    list(tibble(y = 2L), tibble(y = c(1L, 3L)))
-  )
-  expect_equal(
-    gf %>% summarise(x = list(cur_data_all())) %>% pull(),
-    list(tibble(x = "a", y = 2L), tibble(x = "b", y = c(1L, 3L)))
-  )
-})
-
-test_that("cur_data()/cur_data_all() keeps list columns as lists in rowwise_df (#5901)", {
-  df <- tibble(x = list(tibble(a = 1), tibble(a = 2))) %>%
-    rowwise()
-
-  expect_true(
-    all(summarise(df, test = vec_is_list(cur_data()$x))$test)
-  )
-  expect_true(
-    all(summarise(df, test = vec_is_list(cur_data_all()$x))$test)
-  )
-})
-
 test_that("cur_group_rows() retrieves row position in original data", {
   df <- tibble(x = c("b", "a", "b"), y = 1:3)
   gf <- group_by(df, x)
@@ -74,27 +53,10 @@ test_that("cur_group_rows() retrieves row position in original data", {
   )
 })
 
-test_that("cur_data() and cur_data_all() work sequentially", {
-  df <- tibble(a = 1)
-  expect_equal(
-    mutate(df, x = ncol(cur_data()), y = ncol(cur_data())),
-    tibble(a = 1, x = 1, y = 2)
-  )
-
-  gf <- tibble(a = 1, b = 2) %>% group_by(a)
-  expect_equal(
-    mutate(gf, x = ncol(cur_data_all()), y = ncol(cur_data_all())),
-    group_by(tibble(a = 1, b = 2, x = 2, y = 3), a)
-  )
-})
-
 test_that("give useful error messages when not applicable", {
   expect_snapshot({
     (expect_error(n()))
 
-    (expect_error(cur_data()))
-    (expect_error(cur_data_all()))
-
     (expect_error(cur_column()))
     (expect_error(cur_group()))
     (expect_error(cur_group_id()))
@@ -102,3 +64,10 @@ test_that("give useful error messages when not applicable", {
   })
 
 })
+
+test_that("group labels are correctly formatted", {
+  expect_snapshot({
+    group_labels_details(c("a" = 1))
+    group_labels_details(c("a" = 1, "b" = 2))
+  })
+})
