@@ -105,69 +105,69 @@ test_that("empty data frames give consistent outputs", {
 
   dat %>%
     do(data.frame()) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     length() %>%
     expect_equal(0)
   dat %>%
     do(data.frame(y = integer(0))) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(y = "int"))
   dat %>%
     do(data.frame(.)) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(x = "dbl", g = "chr"))
   dat %>%
     do(data.frame(., y = integer(0))) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(x = "dbl", g = "chr", y = "int"))
   dat %>%
     do(y = ncol(.)) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(y = "list"))
 
   # Grouped data frame should have same col types as ungrouped, with addition
   # of grouping variable
   grp %>%
     do(data.frame()) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(g = "chr"))
   grp %>%
     do(data.frame(y = integer(0))) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(g = "chr", y = "int"))
   grp %>%
     do(data.frame(.)) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(x = "dbl", g = "chr"))
   grp %>%
     do(data.frame(., y = integer(0))) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(x = "dbl", g = "chr", y = "int"))
   grp %>%
     do(y = ncol(.)) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(g = "chr", y = "list"))
 
   # A empty grouped dataset should have same types as grp
   emt %>%
     do(data.frame()) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(g = "chr"))
   emt %>%
     do(data.frame(y = integer(0))) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(g = "chr", y = "int"))
   emt %>%
     do(data.frame(.)) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(x = "dbl", g = "chr"))
   emt %>%
     do(data.frame(., y = integer(0))) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(x = "dbl", g = "chr", y = "int"))
   emt %>%
     do(y = ncol(.)) %>%
-    vapply(type_sum, character(1)) %>%
+    vapply(pillar::type_sum, character(1)) %>%
     expect_equal(c(g = "chr", y = "list"))
 })
 
@@ -194,13 +194,16 @@ test_that("do() gives meaningful error messages", {
     y = 6:1
   ) %>% group_by(g)
 
-  expect_snapshot(error = TRUE, df %>% do(head, tail))
+  expect_snapshot({
+    (expect_error(df %>% do(head, tail)))
 
-  # unnamed elements must return data frames
-  expect_snapshot(error = TRUE, df %>% ungroup() %>% do(1))
-  expect_snapshot(error = TRUE, df %>% do(1))
-  expect_snapshot(error = TRUE, df %>% do("a"))
+    # unnamed elements must return data frames
+    (expect_error(df %>% ungroup() %>% do(1)))
+    (expect_error(df %>% do(1)))
+    (expect_error(df %>% do("a")))
+
+    # can't use both named and unnamed args
+    (expect_error(df %>% do(x = 1, 2)))
+  })
 
-  # can't use both named and unnamed args
-  expect_snapshot(error = TRUE, df %>% do(x = 1, 2))
 })
